@@ -7,6 +7,28 @@
 #' @name mwaved
 #' @title Multichannel wavelet deconvolution with long memory using mwaved.
 #'
+#' @useDynLib mwaved, .registration = TRUE
+#' @importFrom Rcpp sourceCpp
+#' @importFrom grid grid.layout
+#' @importFrom grid grid.newpage 
+#' @importFrom grid pushViewport 
+#' @importFrom grid viewport 
+#' @importFrom shiny runApp 
+#' @importFrom graphics abline 
+#' @importFrom graphics axTicks 
+#' @importFrom graphics axis 
+#' @importFrom graphics grid 
+#' @importFrom graphics lines 
+#' @importFrom graphics matlines 
+#' @importFrom graphics matplot 
+#' @importFrom graphics par 
+#' @importFrom graphics plot 
+#' @importFrom graphics points 
+#' @importFrom graphics segments 
+#' @importFrom grDevices devAskNewPage 
+#' @importFrom stats dgamma 
+#' @importFrom stats mvfft 
+#' @importFrom stats rnorm
 #' @description \code{mwaved} computes the Wavelet deconvolution estimate of a common signal present in multiple channels that have possible different levels of blur and additive error. More information about each function can be found in its help documentation.
 #'
 #' @details \code{mwaved} uses the WaveD wavelet deconvolution paradigm and is based on the \code{waved} R-package given by Raimondo and Stewart (2007). It generalises the approach by allowing a multichannel signal instead of a single channel signal and allows long memory errors within each channel (independent of each channel). See Kulik, Sapatinas and Wishart (2014) for theoretical results and a short numerical investigation. The \code{mwaved} package also uses the external C FFTW library described in Frigo and Johnson, (2005) to dramatically increase the speed of the computations. Detailed information and instructions for implementation are available at \url{http://www.fftw.org}.
@@ -28,9 +50,10 @@ NULL
 #' @details Function creates a matrix of dimension n by m which contains appropriate entries for the case when a direct multichannel signal is observed. That is, no blurring operator is apparent. This is the default argument for the blurring matrix to all the multichannel functions in the \code{mwaved} package.
 #' @param n Number of observations in each channel
 #' @param m Number of channels
+#' @export
 directBlur <- function(n, m = 1){
   stopifnot(is.vector(n), length(n)==1, is.vector(m), length(m) == 1)
-  .Call('mwaved_directBlur', n, m)
+  .Call(`_mwaved_directBlur`, n, m)
 }
 
 #' @name detectBlur
@@ -38,12 +61,13 @@ directBlur <- function(n, m = 1){
 #' @description Detect the form of the input blur matrix, G
 #' @details Detects if the input blur matrix, G, has uniform structure in being of direct blur type everywhere or box.car type everywhere. In those cases, it will return a character string 'direct' or 'box.car' respectively, otherwise it returns 'smooth'. This is done in the direct blur case by checking that the mvfft(G) is equal to 1 everywhere (complex part is zero everywhere) and in the box.car case by checking that each column has two unique values, a zero and positive value. If the blur type is not identified to be direct or box.car, the string 'smooth' is returned.
 #' @param G The input blur matrix to be analysed and checked whether it corresponds to direct blur or box.car blur.
+#' @export
 detectBlur <- function(G) {
   stopifnot(is.matrix(G), !is.complex(G))
-  if (.Call('mwaved_directDetect', G)) {
+  if (.Call(`_mwaved_directDetect`, G)) {
     blur <- 'direct'
   } else {
-    if (.Call('mwaved_boxcarDetect', G)) {
+    if (.Call(`_mwaved_boxcarDetect`, G)) {
       blur <- 'box.car'
     } else {
       blur <- 'smooth'
@@ -59,6 +83,7 @@ detectBlur <- function(G) {
 #' \item 'smooth': Blur that has smooth decay in the Fourier domain.
 #' \item 'box.car': Blur that is of box.car type.
 #' }
+#' @export
 resolutionMethod <- function(blur) {
   stopifnot(is.character(blur), length(blur) == 1)
   switch(blur,
@@ -175,13 +200,13 @@ feasibleShrinkage <- function(shrinkType){
 #' Y <- sapply(1:3, function(i) sig[i]* rnorm(n))
 #' # Estimate the noise levels
 #' multiSigma(Y, deg = 3)
-#'
+#' @export
 multiSigma <- function(Y, deg = 3L){
   stopifnot(is.numeric(Y), !is.complex(Y), is.numeric(deg), length(deg) == 1)
   Y <- as.matrix(Y)
   n <- dim(Y)[1]
   feasibleLength(n)
-  .Call(mwaved_multiSigma, Y, deg)
+  .Call(`_mwaved_multiSigma`, Y, deg)
 }
 
 #' @title Meyer wavelet projection given a set of wavelet coefficients
@@ -217,6 +242,7 @@ multiSigma <- function(Y, deg = 3L){
 #' ltys <-  c(1, 1:length(j))
 #' matlines(x, sapply(j, function(i) multiProj(beta, j1 = i)), type = 'l', col = lcols[-1])
 #' legend("bottomright", legend = c("Signal", paste('j1 =', j)), col = lcols, lty =ltys)
+#' @export
 multiProj <- function(beta, j1 = log2(length(beta$coef)) - 1) {
   stopifnot(class(beta) == 'waveletCoef')
   coefs <- beta$coef
@@ -225,7 +251,7 @@ multiProj <- function(beta, j1 = log2(length(beta$coef)) - 1) {
   n <- length(coefs)
   jvals <- feasibleResolutions(n, j0, j1)
   
-  .Call('mwaved_multiProj', coefs, jvals$j0, jvals$j1, deg)
+  .Call(`_mwaved_multiProj`, coefs, jvals$j0, jvals$j1, deg)
 }
 
 #' @title Resolution level thresholds for hard thresholded wavelet deconvolution estimator
@@ -273,6 +299,7 @@ multiProj <- function(beta, j1 = log2(length(beta$coef)) - 1) {
 #' @references
 #' Kulik, R., Sapatinas, T. and Wishart, J.R. (2014) \emph{Multichannel wavelet deconvolution with long range dependence. Upper bounds on the L_p risk}  Appl. Comput. Harmon. Anal. (to appear in).
 #' \url{http://dx.doi.org/10.1016/j.acha.2014.04.004}
+#' @export
 multiThresh <- function(Y, G = directBlur(nrow(as.matrix(Y)), ncol(as.matrix(Y))), alpha = rep(1,dim(as.matrix(Y))[2]), 
                         resolution = resolutionMethod(detectBlur(G)), j0 = 3L, j1 = NA_integer_, eta = NA_real_, deg = 3L) {
   stopifnot(!is.complex(Y), !is.complex(G))
@@ -287,7 +314,7 @@ multiThresh <- function(Y, G = directBlur(nrow(as.matrix(Y)), ncol(as.matrix(Y))
   alpha <- feasibleAlpha(dimY[2], alpha)
   feasibleMethod(resolution)
   blurCheck(G, resolution)
-  .Call('mwaved_multiThresh', Y, G, alpha, resolution, jvals$j0, jvals$j1, eta, deg)
+  .Call(`_mwaved_multiThresh`, Y, G, alpha, resolution, jvals$j0, jvals$j1, eta, deg)
 }
 
 #' @title Wavelet coefficient estimation from a multichannel signal
@@ -335,6 +362,7 @@ multiThresh <- function(Y, G = directBlur(nrow(as.matrix(Y)), ncol(as.matrix(Y))
 #' # Compute true wavelet coefficients
 #' trueCoefs <- multiCoef(signal)
 #' plot(trueCoefs)
+#' @export
 multiCoef <- function(Y, G = directBlur(nrow(as.matrix(Y)), ncol(as.matrix(Y))), alpha = rep(1,dim(as.matrix(Y))[2]),
                       resolution = resolutionMethod(detectBlur(G)), j0 = 3L, j1 = NA_integer_, eta = NA_real_, deg = 3L) {
   stopifnot(!is.complex(Y), !is.complex(G))
@@ -352,7 +380,7 @@ multiCoef <- function(Y, G = directBlur(nrow(as.matrix(Y)), ncol(as.matrix(Y))),
   feasibleMethod(resolution)
   blurCheck(G, resolution)
   # Pass to C code
-  .Call('mwaved_multiCoef', Y, G, alpha, jvals$j0, jvals$j1, deg)
+  .Call(`_mwaved_multiCoef`, Y, G, alpha, jvals$j0, jvals$j1, deg)
 }
 
 #' @title Apply thresholding regime to a set of wavelet coefficients
@@ -411,6 +439,7 @@ multiCoef <- function(Y, G = directBlur(nrow(as.matrix(Y)), ncol(as.matrix(Y))),
 #' beta <- multiCoef(Y, G)
 #' betaShrunk <- waveletThresh(beta, thresh)
 #' plot(beta, betaShrunk)
+#' @export
 waveletThresh <- function(beta, thresh, shrinkType = 'hard'){
   stopifnot(class(beta) == "waveletCoef", is.numeric(thresh), all(thresh > 0))
   nthr <- length(thresh)
@@ -434,7 +463,7 @@ waveletThresh <- function(beta, thresh, shrinkType = 'hard'){
     warning("Thresh input length too long, higher threshold elements ignored.")
     thresh <- thresh[1:req]
   }
-  return(.Call('mwaved_waveletThresh', beta$coef, thresh, shrinkType, beta$j0, beta$deg))
+  return(.Call(`_mwaved_waveletThresh`, beta$coef, thresh, shrinkType, beta$j0, beta$deg))
 }
 
 
@@ -476,7 +505,7 @@ waveletThresh <- function(beta, thresh, shrinkType = 'hard'){
 #' summary(mWaveDObj)
 #' 
 #' @seealso \code{\link{plot.mWaveD}} and \code{\link{summary.mWaveD}}
-#' 
+#' @export
 multiWaveD <- function(Y, G = directBlur(nrow(as.matrix(Y)), ncol(as.matrix(Y))), alpha = rep(1,dim(as.matrix(Y))[2]),
                        j0 = 3L, j1 = NA_integer_, resolution = resolutionMethod(detectBlur(G)), eta = NA_real_,
                        thresh = as.numeric(c()), shrinkType = "hard", deg = 3L) {
@@ -496,7 +525,7 @@ multiWaveD <- function(Y, G = directBlur(nrow(as.matrix(Y)), ncol(as.matrix(Y)))
   shrinkType <- tolower(shrinkType)
   feasibleShrinkage(shrinkType)
   # Pass to C code
-  return(.Call('mwaved_multiWaveD', Y, G, alpha, resolution, blur, jvals$j0, jvals$j1, eta, thresh, shrinkType, deg))
+  return(.Call(`_mwaved_multiWaveD`, Y, G, alpha, resolution, blur, jvals$j0, jvals$j1, eta, thresh, shrinkType, deg))
 }
 
 #' @title Wavelet deconvolution signal estimate from the noisy multichannel convoluted signal
@@ -542,7 +571,7 @@ multiWaveD <- function(Y, G = directBlur(nrow(as.matrix(Y)), ncol(as.matrix(Y)))
 #' matplot(x, Y, type = 'l', main = 'Noisy multichannel signal')
 #' plot(x, signal, type = 'l', lty = 2, main = 'True Doppler signal and estimate', col = 'red')
 #' lines(x, dopplerEstimate)
-#' 
+#' @export
 multiEstimate <- function(Y, G = directBlur(nrow(as.matrix(Y)), ncol(as.matrix(Y))), alpha = rep(1,dim(as.matrix(Y))[2]), 
                           resolution = resolutionMethod(detectBlur(G)), sigma = as.numeric(c()), j0 = 3L, j1 = NA_integer_, 
                           eta = NA_real_, thresh = multiThresh(as.matrix(Y), G = G, alpha = alpha,
@@ -563,7 +592,7 @@ multiEstimate <- function(Y, G = directBlur(nrow(as.matrix(Y)), ncol(as.matrix(Y
   shrinkType <- tolower(shrinkType)
   feasibleShrinkage(shrinkType)
   # Pass to C code
-  .Call('mwaved_multiEstimate', Y, G, alpha, resolution, blur, sigma, jvals$j0, jvals$j1, eta, thresh, shrinkType, deg)
+  .Call(`_mwaved_multiEstimate`, Y, G, alpha, resolution, blur, sigma, jvals$j0, jvals$j1, eta, thresh, shrinkType, deg)
 }
 
 #' @title Find optimal theoretical Eta
@@ -580,13 +609,14 @@ multiEstimate <- function(Y, G = directBlur(nrow(as.matrix(Y)), ncol(as.matrix(Y
 #' @references
 #' Kulik, R., Sapatinas, T. and Wishart, J.R. (2014) \emph{Multichannel wavelet deconvolution with long range dependence. Upper bounds on the L_p risk}  Appl. Comput. Harmon. Anal. (to appear in).
 #' \url{http://dx.doi.org/10.1016/j.acha.2014.04.004}
+#' @export
 theoreticalEta <- function(alpha, blur, G, sigma) {
   feasibleBlur(blur)
   if (blur == 'box.car') {
     eta = 4 * sqrt(min(alpha))
   } else {
     G <- as.matrix(G)
-    eta <- .Call('mwaved_theoreticalEta', alpha, blur, mvfft(G), sigma)
+    eta <- .Call(`_mwaved_theoreticalEta`, alpha, blur, mvfft(G), sigma)
   }
   eta
 }
